@@ -6,10 +6,10 @@
 /* SYNOPSIS
 /*	#include <bounce.h>
 /*
-/*	int	bounce_append(flags, id, entry, recipient, relay, dsn)
+/*	int	bounce_append(flags, id, stats, recipient, relay, dsn)
 /*	int	flags;
 /*	const char *id;
-/*	time_t	entry;
+/*	MSG_STATS *stats;
 /*	RECIPIENT *rcpt;
 /*	const char *relay;
 /*	DSN	*dsn;
@@ -36,7 +36,7 @@
 /*	const char *verp_delims;
 /*
 /*	int	bounce_one(flags, queue, id, encoding, sender, envid, ret,
-/*				entry, recipient, relay, dsn)
+/*				stats, recipient, relay, dsn)
 /*	int	flags;
 /*	const char *queue;
 /*	const char *id;
@@ -44,7 +44,7 @@
 /*	const char *sender;
 /*	const char *dsn_envid;
 /*	int	dsn_ret;
-/*	time_t	entry;
+/*	MSG_STATS *stats;
 /*	RECIPIENT *rcpt;
 /*	const char *relay;
 /*	DSN	*dsn;
@@ -99,8 +99,9 @@
 /* .IP id
 /*	The message queue id if the original message file. The bounce log
 /*	file has the same name as the original message file.
-/* .IP entry
-/*	Message arrival time.
+/* .IP stats
+/*	Time stamps from different message delivery stages
+/*	and session reuse count.
 /* .IP rcpt
 /*	Recipient information. See recipient_list(3).
 /* .IP relay
@@ -164,7 +165,7 @@
 
 /* bounce_append - append dsn_text to per-message bounce log */
 
-int     bounce_append(int flags, const char *id, time_t entry,
+int     bounce_append(int flags, const char *id, MSG_STATS *stats,
 		              RECIPIENT *rcpt, const char *relay,
 		              DSN *dsn)
 {
@@ -186,7 +187,7 @@ int     bounce_append(int flags, const char *id, time_t entry,
      */
     if (flags & DEL_REQ_FLAG_MTA_VRFY) {
 	my_dsn.action = "undeliverable";
-	status = verify_append(id, entry, rcpt, relay, &my_dsn,
+	status = verify_append(id, stats, rcpt, relay, &my_dsn,
 			       DEL_RCPT_STAT_BOUNCE);
 	return (status);
     }
@@ -197,7 +198,7 @@ int     bounce_append(int flags, const char *id, time_t entry,
      */
     if (flags & DEL_REQ_FLAG_USR_VRFY) {
 	my_dsn.action = "undeliverable";
-	status = trace_append(flags, id, entry, rcpt, relay, &my_dsn);
+	status = trace_append(flags, id, stats, rcpt, relay, &my_dsn);
 	return (status);
     }
 
@@ -241,9 +242,9 @@ int     bounce_append(int flags, const char *id, time_t entry,
 				ATTR_TYPE_FUNC, dsn_print, (void *) &my_dsn,
 				ATTR_TYPE_END) == 0
 	    && ((flags & DEL_REQ_FLAG_RECORD) == 0
-		|| trace_append(flags, id, entry, rcpt, relay,
+		|| trace_append(flags, id, stats, rcpt, relay,
 				&my_dsn) == 0)) {
-	    log_adhoc(id, entry, rcpt, relay, &my_dsn, log_status);
+	    log_adhoc(id, stats, rcpt, relay, &my_dsn, log_status);
 	    status = (var_soft_bounce ? -1 : 0);
 	} else if ((flags & BOUNCE_FLAG_CLEAN) == 0) {
 	    VSTRING *junk = vstring_alloc(100);
@@ -252,7 +253,7 @@ int     bounce_append(int flags, const char *id, time_t entry,
 	    vstring_sprintf(junk, "%s or %s service failure",
 			    var_bounce_service, var_trace_service);
 	    my_dsn.reason = vstring_str(junk);
-	    status = defer_append(flags, id, entry, rcpt, relay, &my_dsn);
+	    status = defer_append(flags, id, stats, rcpt, relay, &my_dsn);
 	    vstring_free(junk);
 	} else {
 	    status = -1;
@@ -333,7 +334,7 @@ int     bounce_flush_verp(int flags, const char *queue, const char *id,
 int     bounce_one(int flags, const char *queue, const char *id,
 		           const char *encoding, const char *sender,
 		           const char *dsn_envid, int dsn_ret,
-		           time_t entry, RECIPIENT *rcpt,
+		           MSG_STATS *stats, RECIPIENT *rcpt,
 		           const char *relay, DSN *dsn)
 {
     DSN     my_dsn = *dsn;
@@ -353,7 +354,7 @@ int     bounce_one(int flags, const char *queue, const char *id,
      */
     if (flags & DEL_REQ_FLAG_MTA_VRFY) {
 	my_dsn.action = "undeliverable";
-	status = verify_append(id, entry, rcpt, relay, &my_dsn,
+	status = verify_append(id, stats, rcpt, relay, &my_dsn,
 			       DEL_RCPT_STAT_BOUNCE);
 	return (status);
     }
@@ -364,7 +365,7 @@ int     bounce_one(int flags, const char *queue, const char *id,
      */
     if (flags & DEL_REQ_FLAG_USR_VRFY) {
 	my_dsn.action = "undeliverable";
-	status = trace_append(flags, id, entry, rcpt, relay, &my_dsn);
+	status = trace_append(flags, id, stats, rcpt, relay, &my_dsn);
 	return (status);
     }
 
@@ -373,7 +374,7 @@ int     bounce_one(int flags, const char *queue, const char *id,
      * based procedure.
      */
     else if (var_soft_bounce) {
-	return (bounce_append(flags, id, entry, rcpt, relay, &my_dsn));
+	return (bounce_append(flags, id, stats, rcpt, relay, &my_dsn));
     }
 
     /*
@@ -402,9 +403,9 @@ int     bounce_one(int flags, const char *queue, const char *id,
 				ATTR_TYPE_FUNC, dsn_print, (void *) &my_dsn,
 				ATTR_TYPE_END) == 0
 	    && ((flags & DEL_REQ_FLAG_RECORD) == 0
-		|| trace_append(flags, id, entry, rcpt, relay,
+		|| trace_append(flags, id, stats, rcpt, relay,
 				&my_dsn) == 0)) {
-	    log_adhoc(id, entry, rcpt, relay, &my_dsn, "bounced");
+	    log_adhoc(id, stats, rcpt, relay, &my_dsn, "bounced");
 	    status = 0;
 	} else if ((flags & BOUNCE_FLAG_CLEAN) == 0) {
 	    VSTRING *junk = vstring_alloc(100);
@@ -413,7 +414,7 @@ int     bounce_one(int flags, const char *queue, const char *id,
 	    vstring_sprintf(junk, "%s or %s service failure",
 			    var_bounce_service, var_trace_service);
 	    my_dsn.reason = vstring_str(junk);
-	    status = defer_append(flags, id, entry, rcpt, relay, &my_dsn);
+	    status = defer_append(flags, id, stats, rcpt, relay, &my_dsn);
 	    vstring_free(junk);
 	} else {
 	    status = -1;
